# STM32 CLI

[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://travis-ci.org/joemccann/dillinger)

Work with version 0.0.12

- Reading Flash
- Erase Flash

## Features

- Communicate Bootloader STM32 custom
- Test Led Function
- Read BootLoader Version, Name
- Read, Write, Erase internal Flash STM32
- Coming soon Write Firmware, Test Firmware, Update Firmware, Rolling Back Old Version, ...
